@@ -9,7 +9,7 @@ class UniversityStudentClientConfiguration(ClientCredentialsConfigurationMixin,
         client_key,
         client_secret,
         access_token_url="https://api.apps.cam.ac.uk/oauth2/v1/token",
-        base_url="https://api.apps.cam.ac.uk/university-student"
+        base_url="https://api.apps.cam.ac.uk/university-student/v1alpha2"
     ):
 
         ClientCredentialsConfigurationMixin.__init__(
